#Trace les spectres de 6 sources lumineuses, en 6 graphes juxtaposés.
"""
Sources des données :
https://lspdd.org/app/fr/lamps/ (sauf laser)
laser : https://osf.io/x9gm6/files/
"""

#Appel des modules nécessaires :
import matplotlib.pyplot as plt
import pandas as pd

#Extraction des données (fichiers csv) :
incand=pd.read_csv("incandescente.csv", delimiter=',')
fluo=pd.read_csv("tubeFluoCFL.csv", delimiter=',')
led=pd.read_csv("led1.csv", delimiter=',')
laser=pd.read_csv("pic532.csv", delimiter=',')
HPS=pd.read_csv("HPSodium.csv", delimiter=',')
halo=pd.read_csv("halogene.csv", delimiter=',')
soleil=pd.read_csv("sun.csv", delimiter=',')

#création des listes (longueurs d'onde et intensités) :
LOincand=incand["wavelength"]
LOfluo=fluo["wavelength"]
LOled=led["wavelength"]
LOlaser=laser["wavelength"]
LOHPS=HPS["wavelength"]
LOhalo=halo["wavelength"]
LOSoleil=soleil["wavelength"]

Intensiteincand=incand["intensity"]
Intensitefluo=fluo["intensity"]
Intensiteled=led["intensity"]
Intensitelaser=laser["intensity"]
IntensiteHPS=HPS["intensity"]
Intensitehalo=halo["intensity"]
IntensiteSoleil=soleil["intensity"]

#REGLAGES UTILISATEUR :
NB=False#option Noir et Blanc

#Définition de fonction :----------------------------------------------

def degrade(x, y):#remplit les courbes avec un dégradé de couleurs
    if NB==False:
        for i in range(len(x)):
            plt.plot([x[i], x[i]], [0, y[i]], c=cmap((i-min(x))/(700)))
"""
l'argument de cmap() est une normalisation de la gamme de couleurs.
"""

#Paramètres des graphiques :------------------------------------
plt.rcParams["font.family"] = "Ubuntu"#A remplacer par une autre police installée sur l'ordinateur
fig=plt.figure(figsize=(7, 9))#Largeur et hauteur, en pouces
plt.suptitle("Spectres de différentes sources lumineuses", fontsize=16)
plt.subplots_adjust(top=0.9, bottom=0.06, left=0.04, right=0.95, hspace=0.5,wspace=0.1)


#gamme de couleurs choisie (colormap) :
cmap=plt.get_cmap('turbo')

#GRAPHE 1 --------------------------------------------------------
ax1=plt.subplot(321)
plt.title("Soleil")
degrade(LOSoleil, IntensiteSoleil)
plt.plot(LOSoleil, IntensiteSoleil, 'k-')
ax1.set_xlim(350, 800)
ax1.set_yticks([])

#GRAPHE 2 --------------------------------------------------------
ax2=plt.subplot(322)
plt.title("lampe à incandescence")
degrade(LOhalo, Intensitehalo)
plt.plot(LOhalo, Intensitehalo, 'k-')
#degrade(LOincand, Intensiteincand)#inutile
plt.plot(LOincand, Intensiteincand, 'k-')

plt.text(600, 0.010, "classique", fontsize=9)
plt.text(600, 0.05, "halogène", fontsize=9)
ax2.set_xlim(350, 800)
ax2.set_yticks([])

#GRAPHE 3 --------------------------------------------------------
ax3=plt.subplot(323)
plt.title("lampe spectrale sodium haute pression")
ax3.set_xlim(350, 800)
ax3.set_yticks([])
degrade(LOHPS, IntensiteHPS)
plt.plot(LOHPS, IntensiteHPS, 'k-')

#GRAPHE 4 --------------------------------------------------------
ax4=plt.subplot(324)
plt.title("tube fluorescent")
degrade(LOfluo, Intensitefluo)
plt.plot(LOfluo, Intensitefluo, 'k-')
ax4.set_xlim(350, 800)
ax4.set_yticks([])

#GRAPHE 5 --------------------------------------------------------
ax5=plt.subplot(325)
plt.title("lampe à LED")
degrade(LOled, Intensiteled)
plt.plot(LOled, Intensiteled, 'k-')
ax5.set_xlim(350, 800)
ax5.set_yticks([])

#GRAPHE 6 --------------------------------------------------------
ax6=plt.subplot(326)
plt.title("laser")
#degrade(LOlaser, Intensitelaser)#peu utile
plt.plot(LOlaser, Intensitelaser, 'k-')
ax6.set_xlim(500, 700)
ax6.set_yticks([])
#-------------------------------------------------------------------
plt.text(0., -0.25, "Sources : https://lspdd.org/app/fr/lamps/ et (laser) https://osf.io/x9gm6/files/", fontsize=8, transform=ax5.transAxes)
fig.savefig('SpectresLampesdpi200.png', transparent=False, dpi=200)# Création image PNG 
plt.show()
